//
//  JTCalendar.h
//  JTCalendarWidget
//
//  Created by Jim on 1/25/05.
//  Copyright 2005 Jim Thomason (jim@bassetsoftware.com). All rights reserved.
//  http://www.bassetsoftware.com/osx/jtcalendarwidget/
//  Distributed under the terms of the Artistic License
//
// Donations for my hard work are always welcome. :-) They can be paypaled to jim@bassetsoftware.com

#import <Cocoa/Cocoa.h>

#import "JTCalendarDelegateProtocol.h"

@class JTCalendarTextField, JTClickableMatrix, JTCalendarPopup;

#define DECREASE_MONTH	1
#define INCREASE_MONTH	2
#define DECREASE_YEAR	3
#define INCREASE_YEAR	4
#define TODAY			5
#define CURRENT_DATE	6

@interface JTCalendar : NSControl {
	JTCalendarTextField* field;
	JTCalendarPopup* popup;
	
	IBOutlet NSTextField* month;
	IBOutlet NSTextField* year;

	IBOutlet NSMatrix* days;
	
	IBOutlet JTClickableMatrix* dates;
	IBOutlet NSBox* box;
	
	IBOutlet NSView* container;
	
	id <JTCalendarDelegate> delegate;
	
	NSCalendarDate* currentDate;	//this is the current date of this calendar control
	NSCalendarDate* displayDate;	//this is -a- date currently displayed on the calendar. Used only to display
									//which month the user has currently navigated to
	
	NSColor* weekdayColor;
	NSColor* weekendColor;
	NSColor* highlightColor;
	NSColor* backgroundColor;
	
	int sunday;
	int saturday;
	
	BOOL sundayFirst;
	
	BOOL enabled;
	BOOL hidden;
	
	BOOL allowsPast;
	
	//bindings stuff
	NSMutableDictionary* observers;
	
}

/*
	standard accessors/mutators

	The one you'd be most interested in is currentDate, which returns the pop up's current date.
	setCurrentDate sets the current date to something new.
*/

-(NSCalendarDate*) currentDate;
-(void) setCurrentDate:(NSCalendarDate*) newDate;

/* Used internally to set the current date (which normally does not send the action)
	and specify if the action should be sent */
-(void) setCurrentDate:(NSCalendarDate*) newDate andSendAction:(BOOL) send;

/* Used internally to set the current date (which normally does post the observation)
	and specify if a notice should be posted to bindings observers */
-(void) setCurrentDate:(NSCalendarDate*) newDate andPostObservation:(BOOL) post;

-(void) setWeekdayColor:(NSColor*) newWeekdayColor;
-(NSColor*) weekdayColor;

-(void) setWeekendColor:(NSColor*) newWeekendColor;
-(NSColor*) weekendColor;

-(void) setHighlightColor:(NSColor*) newHighlightColor;
-(NSColor*) highlightColor;

-(void) setBackgroundColor:(NSColor*) newBackgroundColor;
-(NSColor*) backgroundColor;

/*
	Some people like to display sundays at the end of the week. This toggle allows it.
	Defaults to "YES" (S M T W T F S)
*/

-(void) setSundayFirst:(BOOL) first;
-(BOOL) sundayFirst;

/*
	Sometimes, it's useful to restrict users to only picking dates in the future (including
	today). Defaults to YES, allowing past selection
*/

-(void) setAllowsPast:(BOOL) past;
-(BOOL) allowsPast;

//delegate methods are defined in JTCalendarDelegateProtocol.h
-(void) setDelegate:(id <JTCalendarDelegate>) newDelegate;
-(id <JTCalendarDelegate>) delegate;

-(void) setEnabled:(BOOL) newEnabled;
-(BOOL) isEnabled;

-(void) setHidden:(BOOL) newHidden;
-(BOOL) isHidden;

//everything else is internal

//The dates matrix calls this method to set the current date based off of
//the day the user has selected in the interface
-(void) setCurrentDateFromSelectedDay:(int) day;

//The buttons in the view govern where to advance the displayDate, governed by the constants defined above
-(IBAction) advance:(id) sender;

//updates the display 
-(void) updateDisplay;

//If the calendar is associated with a field, this shows or hides the calendar (pops it up) as desired
-(void) show;
-(void) hide;

//wires this calendar control up to a text field.
-(void) setField:(JTCalendarTextField*) newField;
-(void) setCalendarPopup:(JTCalendarPopup*) newPopup;

@end
