//
//  JTCalendarDelegateProtocol.h
//  JTCalendarWidget
//
//  Created by Jim on 2/11/05.
//  Copyright 2005 Jim Thomason (jim@bassetsoftware.com). All rights reserved.
//  http://www.bassetsoftware.com/osx/jtcalendarwidget/
//  Distributed under the terms of the Artistic License
//
// Donations for my hard work are always welcome. :-) They can be paypaled to jim@bassetsoftware.com


@protocol JTCalendarDelegate <NSObject> 

/*
	JTCalendarDelegate is a delegate protocol for either JTCalendar or JTCalendarPopup objects.
	Delegates may implement any or all of the delegate methods, but if you explicitly use it
	(MyDelegate : NSObject <JTCalendarDelegate>) then note that you -must- implement them all.
*/

/*
	colorForDate is called during updateDisplay (used internally after setting the current date).
	Delegate may override the color used for this date. Return nil to use the default, which will
	be either the weekday or weekend color, as appropriate.
*/

-(NSColor*) colorForDate:(NSCalendarDate*) date;

/*
	backgroundColorForDate is called during updateDisplay (used internally after setting the current date).
	Delegate may override the color used for this date. Return nil to use the default, which is
	NSClearColor. Dates normally do not draw their background, instead relying upon the calendar's
	default background color to be drawn.
*/

-(NSColor*) backgroundColorForDate:(NSCalendarDate*) date;

/*
	colorForDayHeading is called during updateDisplay (used internally after setting the current date)
	Delegate may override the color used for this date. Return nil to use the default, which will be
	either the weekday or weekend color, as appropriate. Gets a 0 based integer indicating the day.
	Note that 0 will -always- be Sunday, regardless of the setting for sundayFirst
*/

-(NSColor*) colorForDayHeading:(int) day;

/*
	Called when the user clicks on a date. This is to allow fine-tuned date selection. Returns YES
	if the user can select that date, NO if he cannot. Calls NSBeep() if an invalid date is chosen.
	Recommended to be used in conjunction with colorForDate to set a gray color for the date if it
	is invalid.
*/

-(BOOL) canSelectDate:(NSCalendarDate*) date;

@end